@@ -6,6 +6,7 @@ Can be used/invoked as a module, why? because print is a valid debug tool!
 """
 # Import the typing library so variables can be type cast
 from typing import List, Optional, Tuple
+from typing_extensions import TypeAlias
 
 # Import the sys to get any argv used
 import sys
@@ -16,19 +17,19 @@ import random
 from ewccommons import str_lower_list
 from ewccommons.errors import not_what_i_wanted
 
-_Card_ = Tuple[str, str]
+_Card_: TypeAlias = Tuple[str, str]
 """Type Alias Definition
 
 An individual card variable structure.
 """
 
-_Deck_ = List[_Card_]
+_Deck_: TypeAlias = List[_Card_]
 """Type Alias Definition
 
 A deck of cards collection list variable structure.
 """
 
-_Hand_ = List[_Card_]
+_Hand_: TypeAlias = List[_Card_]
 """Type Alias Definition
 
 A hand of cards collection subset list variable structure.
